@@ -3,7 +3,7 @@
     Copyright (C) 2005 by Enrico Ros <eros.kde@email.it>
     Copyright (C) 2005 - 2007 Josef Spillner <spillner@kde.org>
     Copyright (C) 2007 Dirk Mueller <mueller@kde.org>
-    Copyright (C) 2007 Jeremy Whiting <jeremy@scitools.com>
+    Copyright (C) 2007 Jeremy Whiting <jpwhiting@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -59,17 +59,17 @@ DownloadDialog::DownloadDialog(DxsEngine* _engine, QWidget * _parent)
     setButtons(0);
 
     m_engine = _engine;
-    connect(m_engine, SIGNAL(signalProgress(QString, int)), SLOT(slotProgress(QString, int)));
+    connect(m_engine, SIGNAL(signalProgress(QString,int)), SLOT(slotProgress(QString,int)));
     connect(m_engine, SIGNAL(signalEntryChanged(KNS::Entry*)), SLOT(slotEntryChanged(KNS::Entry*)));
     connect(m_engine, SIGNAL(signalPayloadFailed(KNS::Entry*)), SLOT(slotPayloadFailed(KNS::Entry*)));
     connect(m_engine, SIGNAL(signalPayloadLoaded(KUrl)), SLOT(slotPayloadLoaded(KUrl)));
     connect(m_engine, SIGNAL(signalProvidersFailed()), SLOT(slotProvidersFailed()));
     connect(m_engine, SIGNAL(signalEntriesFailed()), SLOT(slotEntriesFailed()));
 
-    connect(m_engine, SIGNAL(signalEntryLoaded(KNS::Entry*, const KNS::Feed*, const KNS::Provider*)),
-            this, SLOT(slotEntryLoaded(KNS::Entry*, const KNS::Feed*, const KNS::Provider*)));
-    connect(m_engine, SIGNAL(signalEntryRemoved(KNS::Entry*, const KNS::Feed*)),
-            this, SLOT(slotEntryRemoved(KNS::Entry *, const KNS::Feed *)));
+    connect(m_engine, SIGNAL(signalEntryLoaded(KNS::Entry*,const KNS::Feed*,const KNS::Provider*)),
+            this, SLOT(slotEntryLoaded(KNS::Entry*,const KNS::Feed*,const KNS::Provider*)));
+    connect(m_engine, SIGNAL(signalEntryRemoved(KNS::Entry*,const KNS::Feed*)),
+            this, SLOT(slotEntryRemoved(KNS::Entry*,const KNS::Feed*)));
 
     // initialize the private classes
     messageTimer = new QTimer(this);
@@ -92,16 +92,16 @@ DownloadDialog::DownloadDialog(DxsEngine* _engine, QWidget * _parent)
     // create the delegate
     mDelegate = new ItemsViewDelegate(m_listView, this);
     m_listView->setItemDelegate(mDelegate);
-    connect(mDelegate, SIGNAL(performAction(DownloadDialog::EntryAction, KNS::Entry *)),
-            SLOT(slotPerformAction(DownloadDialog::EntryAction, KNS::Entry *)));
+    connect(mDelegate, SIGNAL(performAction(DownloadDialog::EntryAction,KNS::Entry*)),
+            SLOT(slotPerformAction(DownloadDialog::EntryAction,KNS::Entry*)));
 
     // create the filter model
     m_filteredModel = new QSortFilterProxyModel(this);
     m_filteredModel->setFilterRole(ItemsModel::kNameRole);
     m_filteredModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     m_listView->setModel(m_filteredModel);
-    connect(m_listView->selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)),
-            this, SLOT(slotListIndexChanged(const QModelIndex &, const QModelIndex &)));
+    connect(m_listView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+            this, SLOT(slotListIndexChanged(QModelIndex,QModelIndex)));
 
     // create left picture widget (if picture found)
     //QPixmap p( KStandardDirs::locate( "data", "knewstuff/pics/ghns.png" ) );
@@ -112,12 +112,12 @@ DownloadDialog::DownloadDialog(DxsEngine* _engine, QWidget * _parent)
 
     connect(m_sourceCombo, SIGNAL(currentIndexChanged(int)), SLOT(slotLoadProviderDXS()));
     connect(m_sortCombo, SIGNAL(currentIndexChanged(int)), SLOT(slotSortingSelected(int)));
-    connect(m_searchEdit, SIGNAL(textChanged(const QString &)), SLOT(slotSearchTextChanged()));
+    connect(m_searchEdit, SIGNAL(textChanged(QString)), SLOT(slotSearchTextChanged()));
     connect(m_searchEdit, SIGNAL(editingFinished()), SLOT(slotUpdateSearch()));
 
     // FIXME: not sure if this is better, or setting openExternalLinks
-    //connect( m_providerLinkLabel, SIGNAL( linkActivated(const QString &)),
-    //        KToolInvocation::self(), SLOT(invokeBrowser(const QString &)));
+    //connect( m_providerLinkLabel, SIGNAL(linkActivated(QString)),
+    //        KToolInvocation::self(), SLOT(invokeBrowser(QString)));
 
     // load the last size from config
     KConfigGroup group(KGlobal::config(), ConfigGroup);
@@ -219,7 +219,7 @@ void DownloadDialog::slotPerformAction(DownloadDialog::EntryAction action, KNS::
         break;
     case kCollabComment: {
         // open comment dialog
-        KDXSComment * commentDialog = new KDXSComment(this);
+        QPointer<KDXSComment> commentDialog = new KDXSComment(this);
         int ret = commentDialog->exec();
         if (ret == QDialog::Accepted) {
             QString s = commentDialog->comment();
@@ -227,11 +227,12 @@ void DownloadDialog::slotPerformAction(DownloadDialog::EntryAction action, KNS::
                 dxs->call_comment(entry->idNumber(), s);
             }
         }
+	delete commentDialog;
     }
     break;
     case kCollabRate: {
         // prompt for rating, and send to provider
-        KDXSRating * ratingDialog = new KDXSRating(this);
+        QPointer<KDXSRating> ratingDialog = new KDXSRating(this);
         int ret = ratingDialog->exec();
         if (ret == QDialog::Accepted) {
             int rating = ratingDialog->rating();
@@ -239,6 +240,7 @@ void DownloadDialog::slotPerformAction(DownloadDialog::EntryAction action, KNS::
                 dxs->call_rating(entry->idNumber(), rating);
             }
         }
+	delete ratingDialog;
     }
     break;
     }
@@ -309,7 +311,7 @@ void DownloadDialog::slotResetMessage() // SLOT
 
 void DownloadDialog::slotNetworkTimeout() // SLOT
 {
-    displayMessage(i18n("Timeout. Check Internet connection!"), KTitleWidget::ErrorMessage);
+    displayMessage(i18n("Timeout. Check Internet connection."), KTitleWidget::ErrorMessage);
 }
 
 void DownloadDialog::slotSortingSelected(int sortType)   // SLOT
@@ -511,14 +513,15 @@ void DownloadDialog::slotInfo(QString provider, QString server, QString version)
 
 void DownloadDialog::slotComments(QStringList comments)
 {
-    KDXSComments commentsdlg(this);
+    QPointer<KDXSComments> commentsdlg = new KDXSComments(this);
 
     for (QStringList::const_iterator it = comments.constBegin(); it != comments.constEnd(); ++it) {
         //kDebug() << "Comment: " << (*it);
-        commentsdlg.addComment("foo", (*it));
+        commentsdlg->addComment("foo", (*it));
     }
 
-    commentsdlg.exec();
+    commentsdlg->exec();
+    delete commentsdlg;
 }
 
 ///////////////// DXS ////////////////////
